@@ -1,6 +1,6 @@
 /*****************************************************************************
  *  Written by Chris Dunlap <cdunlap@llnl.gov>.
- *  Copyright (C) 2007-2016 Lawrence Livermore National Security, LLC.
+ *  Copyright (C) 2007-2017 Lawrence Livermore National Security, LLC.
  *  Copyright (C) 2002-2007 The Regents of the University of California.
  *  UCRL-CODE-155910.
  *
@@ -32,10 +32,8 @@
 
 #include <assert.h>
 #include <errno.h>
-#include <grp.h>
 #include <limits.h>
 #include <pthread.h>
-#include <pwd.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -44,9 +42,11 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <munge.h>
+#include "common.h"
 #include "license.h"
 #include "log.h"
 #include "posignal.h"
+#include "query.h"
 #include "version.h"
 
 
@@ -366,8 +366,6 @@ parse_cmdline (conf_t conf, int argc, char **argv)
     long int       l;
     unsigned long  u;
     int            multiplier;
-    struct passwd *pw_ptr;
-    struct group  *gr_ptr;
     munge_err_t    e;
 
     opterr = 0;                         /* suppress default getopt err msgs */
@@ -477,20 +475,9 @@ parse_cmdline (conf_t conf, int argc, char **argv)
                 conf->num_payload = (int) (l * multiplier);
                 break;
             case 'u':
-                if ((pw_ptr = getpwnam (optarg)) != NULL) {
-                    i = pw_ptr->pw_uid;
-                }
-                else {
-                    errno = 0;
-                    l = strtol (optarg, &p, 10);
-                    if (((errno == ERANGE)
-                                && ((l == LONG_MIN) || (l == LONG_MAX)))
-                            || (optarg == p) || (*p != '\0')
-                            || (l < 0) || (l > INT_MAX)) {
-                        log_err (EMUNGE_SNAFU, LOG_ERR,
-                            "Unrecognized user \"%s\"", optarg);
-                    }
-                    i = (int) l;
+                if (query_uid (optarg, (uid_t *) &i) < 0) {
+                    log_err (EMUNGE_SNAFU, LOG_ERR,
+                        "Unrecognized user \"%s\"", optarg);
                 }
                 e = munge_ctx_set (conf->ctx, MUNGE_OPT_UID_RESTRICTION, i);
                 if (e != EMUNGE_SUCCESS) {
@@ -500,20 +487,9 @@ parse_cmdline (conf_t conf, int argc, char **argv)
                 }
                 break;
             case 'g':
-                if ((gr_ptr = getgrnam (optarg)) != NULL) {
-                    i = gr_ptr->gr_gid;
-                }
-                else {
-                    errno = 0;
-                    l = strtol (optarg, &p, 10);
-                    if (((errno == ERANGE)
-                                && ((l == LONG_MIN) || (l == LONG_MAX)))
-                            || (optarg == p) || (*p != '\0')
-                            || (l < 0) || (l > INT_MAX)) {
-                        log_err (EMUNGE_SNAFU, LOG_ERR,
-                            "Unrecognized group \"%s\"", optarg);
-                    }
-                    i = (int) l;
+                if (query_gid (optarg, (gid_t *) &i) < 0) {
+                    log_err (EMUNGE_SNAFU, LOG_ERR,
+                        "Unrecognized group \"%s\"", optarg);
                 }
                 e = munge_ctx_set (conf->ctx, MUNGE_OPT_GID_RESTRICTION, i);
                 if (e != EMUNGE_SUCCESS) {
